# -*- coding: utf-8 -*-
#------------------------------------------------------------
# pelisalacarta - XBMC Plugin
# seriesblanco_tfm - Testing for Maintenance
# http://blog.tvalacarta.info/plugin-xbmc/pelisalacarta/
#------------------------------------------------------------

from core.scrapertools import *
from core.item import Item
from servers import servertools

__channel__ = "seriesblanco_tfm"
__category__ = "S,VOS"
__type__ = "generic"
__title__ = "SeriesBlanco TfM"
__language__ = "ES"
__date__ = "08/05/2016"
__version__ = "2016050801"

host = "http://seriesblanco.com/"

idiomas = {'es':'Español','la':'Latino','vos':'VOS','vo':'VO', 'japovose':'VOSE', 'jp-sub':'VOSE', 'jpsub':'VOSE', 'japo':'VOSE', 'jp':'VOSE'}

def isGeneric():
    return True

def mainlist( item ):
    logger.info( "[seriesblanco_tfm.py] mainlist" )
    return series(
        Item(
            url = urlparse.urljoin( host, "lista_series/" )
        )
    )

def series( item ):
    logger.info( "[seriesblanco_tfm.py] series" )
    itemlist=[]

    data = cache_page( item.url )
    data = re.sub( r"\n|\r|\t|\s{2}|&nbsp;|<Br>|<BR>|<br>|<br/>|<br />|-\s", "", data )
    data = re.sub( r"<!--.*?-->", "", data )
    data = unicode( data, "iso-8859-1", errors="replace" ).encode( "utf-8" )

    patron = "<li><a href='([^']+)' title='([^']+)'>[^<]+</a></li>"
    matches = re.compile( patron, re.DOTALL ).findall( data )

    for scrapedurl, scrapedtitle in matches:
        itemlist.append(
            Item(
                channel = __channel__,
                title = scrapedtitle,
                url = urlparse.urljoin( host, scrapedurl ),
                action = "episodios",
                show = scrapedtitle
            )
        )
    return itemlist

def episodios( item ):
    logger.info( "[seriesblanco_tfm.py] episodios" )
    itemlist = []

    data = cache_page( item.url )
    data = re.sub( r"\n|\r|\t|\s{2}|&nbsp;|<Br>|<BR>|<br>|<br/>|<br />|-\s", "", data )
    data = re.sub( r"<!--.*?-->", "", data )
    data = unicode( data, "iso-8859-1", errors="replace" ).encode( "utf-8" )

    data = re.sub( r"a></td><td> <img src=/banderas/", "a><idioma/", data )
    data = re.sub( r"<img src=/banderas/", "|", data )
    data = re.sub( r"\s\|", "|", data )
    data = re.sub( r"\.png border='\d+' height='\d+' width='\d+'[^>]+><", "/idioma><", data )
    data = re.sub( r"\.png border='\d+' height='\d+' width='\d+'[^>]+>", "", data )

    patron = "<a href='([^']+)'>([^<]+)</a><idioma/([^/]+)/idioma>"
    matches = re.compile( patron, re.DOTALL).findall( data )

    for scrapedurl, scrapedtitle, scrapedidioma in matches:
        idioma = "";
        for i in scrapedidioma.split("|"):
            idioma+= " [" + idiomas[i] + "]"
        title = item.title + " - " + scrapedtitle + idioma
        itemlist.append(
            Item(
                channel = __channel__,
                title = title,
                url = urlparse.urljoin( host, scrapedurl ),
                action = "findvideos",
                show = item.show
            )
        )
    if len(itemlist) == 0 and "<title>404 Not Found</title>" in data:
        itemlist.append(
            Item(
                channel = __channel__,
                title = "la url '" + item.url + "' parece no estar disponible en la web. Iténtalo más tarde.",
                url = item.url,
                action = "series"
            )
        )
    if config.get_library_support() and len(itemlist)>0:
        itemlist.append(
            Item(
                channel = __channel__,
                title = "Añadir esta serie a la biblioteca de XBMC",
                url = item.url,
                action = "add_serie_to_library",
                extra = "episodios",
                show = item.show
            )
        )
    return itemlist

def findvideos( item ):
    logger.info( "[seriesblanco_tfm.py] findvideos" )
    itemlist = []

    data = cache_page(item.url)

    ## Si no hay enlaces online y descarga posiblemente se esté usando la API.
    if len( re.compile( '(<tr id="norecords">)', re.DOTALL).findall( data ) ) > 1:

        ## -- Opción 1 ------------------------------------------------------------------
        ## Se asume que la API es ajax.php, usa el método POST y que los parámetros se generan con un algoritmo determinado.
        api = "http://seriesblanco.com/ajax.php"

        serie = b64( b64( b64( item.url.split('/')[4],                           action=1, inverse=1 )[:-1], action=1 )[:-1], action=1 )[:-1]
        temp =  b64( b64( b64( item.url.split('/')[5].replace('temporada-', ''), action=1, inverse=1 )[:-1], action=1 )[:-1], action=1 )[:-1]
        cap =   b64( b64( b64( item.url.split('/')[6].replace('capitulo-', ''),  action=1, inverse=1 )[:-1], action=1 )[:-1], action=1 )[:-1]
        post = "action=load&serie=%s&temp=%s&cap=%s" % ( serie, temp, cap )

        data = cache_page( api, post=post )
        ## ------------------------------------------------------------------------------

        '''
        ## -- Opción 2 ------------------------------------------------------------------
        ## Los parámetros se sacan de los datos de la url.
        api = find_single_match( data.replace("'", '"'), ':\s"([^"]+)"[^:]+:\s"([^"]+)"[^:]+:\s"(action=load[^"]+)"' )

        exec "data = cache_page(host+api[0], " + api[1].lower() + "=api[2])"
        ## ------------------------------------------------------------------------------
        '''

    data = re.sub( r'<span></span>', '<span>SD</span>', data )

    ## Dividir los datos en dos bloques, el primero "Ver" y segundo "Descargar"
    onl_dow = re.compile( '(<table class="[^"]+">.*?</table>)', re.DOTALL).findall( data )

    ## Patrón común para "Ver" y "Descargar"
    patron = '<tr class="[^"]+">.*?'
    patron+= '<span>([^<]+)</span>.*?'   ## scrapedfecha
    patron+= '/banderas/([^\.]+)\..*?'   ## scrapedidioma
    patron+= 'href="([^"]+)".*?'         ## scrapedurl
    patron+= '/servidores/([^\.]+)\..*?' ## scrapedservidor
    patron+= '<span>([^<]+)</span>.*?'   ## scrapeduploader
    patron+= '<span>([^<]+)</span>'      ## scrapedsubcalidad

    ## Para el título del primer bloque
    tipo = "Ver en "
    for bloque in onl_dow:
        matches = re.compile( patron, re.DOTALL ).findall( bloque )
        for scrapedfecha, scrapedidioma, scrapedurl, scrapedservidor, scrapeduploader, scrapedsubcalidad in matches:
            title = tipo + scrapedservidor + " [" + idiomas[scrapedidioma] + "] [" + scrapedsubcalidad + "] (" + scrapeduploader + ": "+ scrapedfecha + ")"
            itemlist.append(
                Item(
                    channel = __channel__,
                    title = title,
                    url = urlparse.urljoin( host, scrapedurl ),
                    action = "play",
                    show = item.show
                )
            )
        ## Para el título del segundo bloque
        tipo = "Descargar en "
    return itemlist

def play( item ):
    logger.info( "[seriesblanco_tfm.py] play url = " + item.url )

    if "seriesblanco" in item.url:
        data = cache_page( item.url )

        patron = "<input type='button' value='Ver o Descargar' onclick='window.open\(\"([^\"]+)\"\);'/>"
        url = find_single_match( data, patron )
    else:
        url = item.url

    itemlist = servertools.find_video_items( data=url )

    for videoitem in itemlist:
        videoitem.title = item.title
        videoitem.channel = __channel__

    return itemlist

## Decode/encode
def b64( text, action=0, inverse=0 ):
    import base64
    if inverse != 0: text = text[::-1]
    de_en = "de" if action == 0 else "en"
    exec "text = base64." + de_en + "codestring( text )"
    return text
